@@ -15,7 +15,7 @@ class GetSkinRespond:
             if "skins" in self._json:
                 self.skins = []
                 for i in self._json["skins"]:
-                    self.skins.append(Skin.get_skin(i))
+                    self.skins.append(Skin.create(i))
                 if len(self.skins) == 0:
                     self.skins=None
 
